import { z } from 'zod';
/**
 * @see {@link https://datatracker.ietf.org/doc/html/rfc8414}
 * @note we do not enforce https: scheme in URIs to support development
 * environments. Make sure to validate the URIs before using it in a production
 * environment.
 */
export declare const oauthAuthorizationServerMetadataSchema: z.ZodObject<{
    issuer: z.ZodEffects<z.ZodEffects<z.ZodString, `http://[::1]${string}` | "http://localhost" | `http://localhost#${string}` | `http://localhost?${string}` | `http://localhost/${string}` | `http://localhost:${string}` | "http://127.0.0.1" | `http://127.0.0.1#${string}` | `http://127.0.0.1?${string}` | `http://127.0.0.1/${string}` | `http://127.0.0.1:${string}` | `https://${string}`, string>, `http://[::1]${string}` | "http://localhost" | `http://localhost#${string}` | `http://localhost?${string}` | `http://localhost/${string}` | `http://localhost:${string}` | "http://127.0.0.1" | `http://127.0.0.1#${string}` | `http://127.0.0.1?${string}` | `http://127.0.0.1/${string}` | `http://127.0.0.1:${string}` | `https://${string}`, string>;
    claims_supported: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
    claims_locales_supported: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
    claims_parameter_supported: z.ZodOptional<z.ZodBoolean>;
    request_parameter_supported: z.ZodOptional<z.ZodBoolean>;
    request_uri_parameter_supported: z.ZodOptional<z.ZodBoolean>;
    require_request_uri_registration: z.ZodOptional<z.ZodBoolean>;
    scopes_supported: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
    subject_types_supported: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
    response_types_supported: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
    response_modes_supported: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
    grant_types_supported: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
    code_challenge_methods_supported: z.ZodOptional<z.ZodArray<z.ZodEnum<["S256", "plain"]>, "many">>;
    ui_locales_supported: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
    id_token_signing_alg_values_supported: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
    display_values_supported: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
    request_object_signing_alg_values_supported: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
    authorization_response_iss_parameter_supported: z.ZodOptional<z.ZodBoolean>;
    authorization_details_types_supported: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
    request_object_encryption_alg_values_supported: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
    request_object_encryption_enc_values_supported: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
    jwks_uri: z.ZodOptional<z.ZodEffects<z.ZodString, `http://[::1]${string}` | "http://localhost" | `http://localhost#${string}` | `http://localhost?${string}` | `http://localhost/${string}` | `http://localhost:${string}` | "http://127.0.0.1" | `http://127.0.0.1#${string}` | `http://127.0.0.1?${string}` | `http://127.0.0.1/${string}` | `http://127.0.0.1:${string}` | `https://${string}`, string>>;
    authorization_endpoint: z.ZodEffects<z.ZodString, `http://[::1]${string}` | "http://localhost" | `http://localhost#${string}` | `http://localhost?${string}` | `http://localhost/${string}` | `http://localhost:${string}` | "http://127.0.0.1" | `http://127.0.0.1#${string}` | `http://127.0.0.1?${string}` | `http://127.0.0.1/${string}` | `http://127.0.0.1:${string}` | `https://${string}`, string>;
    token_endpoint: z.ZodEffects<z.ZodString, `http://[::1]${string}` | "http://localhost" | `http://localhost#${string}` | `http://localhost?${string}` | `http://localhost/${string}` | `http://localhost:${string}` | "http://127.0.0.1" | `http://127.0.0.1#${string}` | `http://127.0.0.1?${string}` | `http://127.0.0.1/${string}` | `http://127.0.0.1:${string}` | `https://${string}`, string>;
    token_endpoint_auth_methods_supported: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
    token_endpoint_auth_signing_alg_values_supported: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
    revocation_endpoint: z.ZodOptional<z.ZodEffects<z.ZodString, `http://[::1]${string}` | "http://localhost" | `http://localhost#${string}` | `http://localhost?${string}` | `http://localhost/${string}` | `http://localhost:${string}` | "http://127.0.0.1" | `http://127.0.0.1#${string}` | `http://127.0.0.1?${string}` | `http://127.0.0.1/${string}` | `http://127.0.0.1:${string}` | `https://${string}`, string>>;
    introspection_endpoint: z.ZodOptional<z.ZodEffects<z.ZodString, `http://[::1]${string}` | "http://localhost" | `http://localhost#${string}` | `http://localhost?${string}` | `http://localhost/${string}` | `http://localhost:${string}` | "http://127.0.0.1" | `http://127.0.0.1#${string}` | `http://127.0.0.1?${string}` | `http://127.0.0.1/${string}` | `http://127.0.0.1:${string}` | `https://${string}`, string>>;
    pushed_authorization_request_endpoint: z.ZodOptional<z.ZodEffects<z.ZodString, `http://[::1]${string}` | "http://localhost" | `http://localhost#${string}` | `http://localhost?${string}` | `http://localhost/${string}` | `http://localhost:${string}` | "http://127.0.0.1" | `http://127.0.0.1#${string}` | `http://127.0.0.1?${string}` | `http://127.0.0.1/${string}` | `http://127.0.0.1:${string}` | `https://${string}`, string>>;
    require_pushed_authorization_requests: z.ZodOptional<z.ZodBoolean>;
    userinfo_endpoint: z.ZodOptional<z.ZodEffects<z.ZodString, `http://[::1]${string}` | "http://localhost" | `http://localhost#${string}` | `http://localhost?${string}` | `http://localhost/${string}` | `http://localhost:${string}` | "http://127.0.0.1" | `http://127.0.0.1#${string}` | `http://127.0.0.1?${string}` | `http://127.0.0.1/${string}` | `http://127.0.0.1:${string}` | `https://${string}`, string>>;
    end_session_endpoint: z.ZodOptional<z.ZodEffects<z.ZodString, `http://[::1]${string}` | "http://localhost" | `http://localhost#${string}` | `http://localhost?${string}` | `http://localhost/${string}` | `http://localhost:${string}` | "http://127.0.0.1" | `http://127.0.0.1#${string}` | `http://127.0.0.1?${string}` | `http://127.0.0.1/${string}` | `http://127.0.0.1:${string}` | `https://${string}`, string>>;
    registration_endpoint: z.ZodOptional<z.ZodEffects<z.ZodString, `http://[::1]${string}` | "http://localhost" | `http://localhost#${string}` | `http://localhost?${string}` | `http://localhost/${string}` | `http://localhost:${string}` | "http://127.0.0.1" | `http://127.0.0.1#${string}` | `http://127.0.0.1?${string}` | `http://127.0.0.1/${string}` | `http://127.0.0.1:${string}` | `https://${string}`, string>>;
    dpop_signing_alg_values_supported: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
    protected_resources: z.ZodOptional<z.ZodArray<z.ZodEffects<z.ZodString, `http://[::1]${string}` | "http://localhost" | `http://localhost#${string}` | `http://localhost?${string}` | `http://localhost/${string}` | `http://localhost:${string}` | "http://127.0.0.1" | `http://127.0.0.1#${string}` | `http://127.0.0.1?${string}` | `http://127.0.0.1/${string}` | `http://127.0.0.1:${string}` | `https://${string}`, string>, "many">>;
    client_id_metadata_document_supported: z.ZodOptional<z.ZodBoolean>;
}, "strip", z.ZodTypeAny, {
    issuer: `http://[::1]${string}` | "http://localhost" | `http://localhost#${string}` | `http://localhost?${string}` | `http://localhost/${string}` | `http://localhost:${string}` | "http://127.0.0.1" | `http://127.0.0.1#${string}` | `http://127.0.0.1?${string}` | `http://127.0.0.1/${string}` | `http://127.0.0.1:${string}` | `https://${string}`;
    authorization_endpoint: `http://[::1]${string}` | "http://localhost" | `http://localhost#${string}` | `http://localhost?${string}` | `http://localhost/${string}` | `http://localhost:${string}` | "http://127.0.0.1" | `http://127.0.0.1#${string}` | `http://127.0.0.1?${string}` | `http://127.0.0.1/${string}` | `http://127.0.0.1:${string}` | `https://${string}`;
    token_endpoint: `http://[::1]${string}` | "http://localhost" | `http://localhost#${string}` | `http://localhost?${string}` | `http://localhost/${string}` | `http://localhost:${string}` | "http://127.0.0.1" | `http://127.0.0.1#${string}` | `http://127.0.0.1?${string}` | `http://127.0.0.1/${string}` | `http://127.0.0.1:${string}` | `https://${string}`;
    jwks_uri?: `http://[::1]${string}` | "http://localhost" | `http://localhost#${string}` | `http://localhost?${string}` | `http://localhost/${string}` | `http://localhost:${string}` | "http://127.0.0.1" | `http://127.0.0.1#${string}` | `http://127.0.0.1?${string}` | `http://127.0.0.1/${string}` | `http://127.0.0.1:${string}` | `https://${string}` | undefined;
    claims_supported?: string[] | undefined;
    claims_locales_supported?: string[] | undefined;
    claims_parameter_supported?: boolean | undefined;
    request_parameter_supported?: boolean | undefined;
    request_uri_parameter_supported?: boolean | undefined;
    require_request_uri_registration?: boolean | undefined;
    scopes_supported?: string[] | undefined;
    subject_types_supported?: string[] | undefined;
    response_types_supported?: string[] | undefined;
    response_modes_supported?: string[] | undefined;
    grant_types_supported?: string[] | undefined;
    code_challenge_methods_supported?: ("S256" | "plain")[] | undefined;
    ui_locales_supported?: string[] | undefined;
    id_token_signing_alg_values_supported?: string[] | undefined;
    display_values_supported?: string[] | undefined;
    request_object_signing_alg_values_supported?: string[] | undefined;
    authorization_response_iss_parameter_supported?: boolean | undefined;
    authorization_details_types_supported?: string[] | undefined;
    request_object_encryption_alg_values_supported?: string[] | undefined;
    request_object_encryption_enc_values_supported?: string[] | undefined;
    token_endpoint_auth_methods_supported?: string[] | undefined;
    token_endpoint_auth_signing_alg_values_supported?: string[] | undefined;
    revocation_endpoint?: `http://[::1]${string}` | "http://localhost" | `http://localhost#${string}` | `http://localhost?${string}` | `http://localhost/${string}` | `http://localhost:${string}` | "http://127.0.0.1" | `http://127.0.0.1#${string}` | `http://127.0.0.1?${string}` | `http://127.0.0.1/${string}` | `http://127.0.0.1:${string}` | `https://${string}` | undefined;
    introspection_endpoint?: `http://[::1]${string}` | "http://localhost" | `http://localhost#${string}` | `http://localhost?${string}` | `http://localhost/${string}` | `http://localhost:${string}` | "http://127.0.0.1" | `http://127.0.0.1#${string}` | `http://127.0.0.1?${string}` | `http://127.0.0.1/${string}` | `http://127.0.0.1:${string}` | `https://${string}` | undefined;
    pushed_authorization_request_endpoint?: `http://[::1]${string}` | "http://localhost" | `http://localhost#${string}` | `http://localhost?${string}` | `http://localhost/${string}` | `http://localhost:${string}` | "http://127.0.0.1" | `http://127.0.0.1#${string}` | `http://127.0.0.1?${string}` | `http://127.0.0.1/${string}` | `http://127.0.0.1:${string}` | `https://${string}` | undefined;
    require_pushed_authorization_requests?: boolean | undefined;
    userinfo_endpoint?: `http://[::1]${string}` | "http://localhost" | `http://localhost#${string}` | `http://localhost?${string}` | `http://localhost/${string}` | `http://localhost:${string}` | "http://127.0.0.1" | `http://127.0.0.1#${string}` | `http://127.0.0.1?${string}` | `http://127.0.0.1/${string}` | `http://127.0.0.1:${string}` | `https://${string}` | undefined;
    end_session_endpoint?: `http://[::1]${string}` | "http://localhost" | `http://localhost#${string}` | `http://localhost?${string}` | `http://localhost/${string}` | `http://localhost:${string}` | "http://127.0.0.1" | `http://127.0.0.1#${string}` | `http://127.0.0.1?${string}` | `http://127.0.0.1/${string}` | `http://127.0.0.1:${string}` | `https://${string}` | undefined;
    registration_endpoint?: `http://[::1]${string}` | "http://localhost" | `http://localhost#${string}` | `http://localhost?${string}` | `http://localhost/${string}` | `http://localhost:${string}` | "http://127.0.0.1" | `http://127.0.0.1#${string}` | `http://127.0.0.1?${string}` | `http://127.0.0.1/${string}` | `http://127.0.0.1:${string}` | `https://${string}` | undefined;
    dpop_signing_alg_values_supported?: string[] | undefined;
    protected_resources?: (`http://[::1]${string}` | "http://localhost" | `http://localhost#${string}` | `http://localhost?${string}` | `http://localhost/${string}` | `http://localhost:${string}` | "http://127.0.0.1" | `http://127.0.0.1#${string}` | `http://127.0.0.1?${string}` | `http://127.0.0.1/${string}` | `http://127.0.0.1:${string}` | `https://${string}`)[] | undefined;
    client_id_metadata_document_supported?: boolean | undefined;
}, {
    issuer: string;
    authorization_endpoint: string;
    token_endpoint: string;
    jwks_uri?: string | undefined;
    claims_supported?: string[] | undefined;
    claims_locales_supported?: string[] | undefined;
    claims_parameter_supported?: boolean | undefined;
    request_parameter_supported?: boolean | undefined;
    request_uri_parameter_supported?: boolean | undefined;
    require_request_uri_registration?: boolean | undefined;
    scopes_supported?: string[] | undefined;
    subject_types_supported?: string[] | undefined;
    response_types_supported?: string[] | undefined;
    response_modes_supported?: string[] | undefined;
    grant_types_supported?: string[] | undefined;
    code_challenge_methods_supported?: ("S256" | "plain")[] | undefined;
    ui_locales_supported?: string[] | undefined;
    id_token_signing_alg_values_supported?: string[] | undefined;
    display_values_supported?: string[] | undefined;
    request_object_signing_alg_values_supported?: string[] | undefined;
    authorization_response_iss_parameter_supported?: boolean | undefined;
    authorization_details_types_supported?: string[] | undefined;
    request_object_encryption_alg_values_supported?: string[] | undefined;
    request_object_encryption_enc_values_supported?: string[] | undefined;
    token_endpoint_auth_methods_supported?: string[] | undefined;
    token_endpoint_auth_signing_alg_values_supported?: string[] | undefined;
    revocation_endpoint?: string | undefined;
    introspection_endpoint?: string | undefined;
    pushed_authorization_request_endpoint?: string | undefined;
    require_pushed_authorization_requests?: boolean | undefined;
    userinfo_endpoint?: string | undefined;
    end_session_endpoint?: string | undefined;
    registration_endpoint?: string | undefined;
    dpop_signing_alg_values_supported?: string[] | undefined;
    protected_resources?: string[] | undefined;
    client_id_metadata_document_supported?: boolean | undefined;
}>;
export type OAuthAuthorizationServerMetadata = z.infer<typeof oauthAuthorizationServerMetadataSchema>;
export declare const oauthAuthorizationServerMetadataValidator: z.ZodEffects<z.ZodEffects<z.ZodObject<{
    issuer: z.ZodEffects<z.ZodEffects<z.ZodString, `http://[::1]${string}` | "http://localhost" | `http://localhost#${string}` | `http://localhost?${string}` | `http://localhost/${string}` | `http://localhost:${string}` | "http://127.0.0.1" | `http://127.0.0.1#${string}` | `http://127.0.0.1?${string}` | `http://127.0.0.1/${string}` | `http://127.0.0.1:${string}` | `https://${string}`, string>, `http://[::1]${string}` | "http://localhost" | `http://localhost#${string}` | `http://localhost?${string}` | `http://localhost/${string}` | `http://localhost:${string}` | "http://127.0.0.1" | `http://127.0.0.1#${string}` | `http://127.0.0.1?${string}` | `http://127.0.0.1/${string}` | `http://127.0.0.1:${string}` | `https://${string}`, string>;
    claims_supported: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
    claims_locales_supported: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
    claims_parameter_supported: z.ZodOptional<z.ZodBoolean>;
    request_parameter_supported: z.ZodOptional<z.ZodBoolean>;
    request_uri_parameter_supported: z.ZodOptional<z.ZodBoolean>;
    require_request_uri_registration: z.ZodOptional<z.ZodBoolean>;
    scopes_supported: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
    subject_types_supported: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
    response_types_supported: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
    response_modes_supported: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
    grant_types_supported: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
    code_challenge_methods_supported: z.ZodOptional<z.ZodArray<z.ZodEnum<["S256", "plain"]>, "many">>;
    ui_locales_supported: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
    id_token_signing_alg_values_supported: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
    display_values_supported: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
    request_object_signing_alg_values_supported: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
    authorization_response_iss_parameter_supported: z.ZodOptional<z.ZodBoolean>;
    authorization_details_types_supported: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
    request_object_encryption_alg_values_supported: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
    request_object_encryption_enc_values_supported: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
    jwks_uri: z.ZodOptional<z.ZodEffects<z.ZodString, `http://[::1]${string}` | "http://localhost" | `http://localhost#${string}` | `http://localhost?${string}` | `http://localhost/${string}` | `http://localhost:${string}` | "http://127.0.0.1" | `http://127.0.0.1#${string}` | `http://127.0.0.1?${string}` | `http://127.0.0.1/${string}` | `http://127.0.0.1:${string}` | `https://${string}`, string>>;
    authorization_endpoint: z.ZodEffects<z.ZodString, `http://[::1]${string}` | "http://localhost" | `http://localhost#${string}` | `http://localhost?${string}` | `http://localhost/${string}` | `http://localhost:${string}` | "http://127.0.0.1" | `http://127.0.0.1#${string}` | `http://127.0.0.1?${string}` | `http://127.0.0.1/${string}` | `http://127.0.0.1:${string}` | `https://${string}`, string>;
    token_endpoint: z.ZodEffects<z.ZodString, `http://[::1]${string}` | "http://localhost" | `http://localhost#${string}` | `http://localhost?${string}` | `http://localhost/${string}` | `http://localhost:${string}` | "http://127.0.0.1" | `http://127.0.0.1#${string}` | `http://127.0.0.1?${string}` | `http://127.0.0.1/${string}` | `http://127.0.0.1:${string}` | `https://${string}`, string>;
    token_endpoint_auth_methods_supported: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
    token_endpoint_auth_signing_alg_values_supported: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
    revocation_endpoint: z.ZodOptional<z.ZodEffects<z.ZodString, `http://[::1]${string}` | "http://localhost" | `http://localhost#${string}` | `http://localhost?${string}` | `http://localhost/${string}` | `http://localhost:${string}` | "http://127.0.0.1" | `http://127.0.0.1#${string}` | `http://127.0.0.1?${string}` | `http://127.0.0.1/${string}` | `http://127.0.0.1:${string}` | `https://${string}`, string>>;
    introspection_endpoint: z.ZodOptional<z.ZodEffects<z.ZodString, `http://[::1]${string}` | "http://localhost" | `http://localhost#${string}` | `http://localhost?${string}` | `http://localhost/${string}` | `http://localhost:${string}` | "http://127.0.0.1" | `http://127.0.0.1#${string}` | `http://127.0.0.1?${string}` | `http://127.0.0.1/${string}` | `http://127.0.0.1:${string}` | `https://${string}`, string>>;
    pushed_authorization_request_endpoint: z.ZodOptional<z.ZodEffects<z.ZodString, `http://[::1]${string}` | "http://localhost" | `http://localhost#${string}` | `http://localhost?${string}` | `http://localhost/${string}` | `http://localhost:${string}` | "http://127.0.0.1" | `http://127.0.0.1#${string}` | `http://127.0.0.1?${string}` | `http://127.0.0.1/${string}` | `http://127.0.0.1:${string}` | `https://${string}`, string>>;
    require_pushed_authorization_requests: z.ZodOptional<z.ZodBoolean>;
    userinfo_endpoint: z.ZodOptional<z.ZodEffects<z.ZodString, `http://[::1]${string}` | "http://localhost" | `http://localhost#${string}` | `http://localhost?${string}` | `http://localhost/${string}` | `http://localhost:${string}` | "http://127.0.0.1" | `http://127.0.0.1#${string}` | `http://127.0.0.1?${string}` | `http://127.0.0.1/${string}` | `http://127.0.0.1:${string}` | `https://${string}`, string>>;
    end_session_endpoint: z.ZodOptional<z.ZodEffects<z.ZodString, `http://[::1]${string}` | "http://localhost" | `http://localhost#${string}` | `http://localhost?${string}` | `http://localhost/${string}` | `http://localhost:${string}` | "http://127.0.0.1" | `http://127.0.0.1#${string}` | `http://127.0.0.1?${string}` | `http://127.0.0.1/${string}` | `http://127.0.0.1:${string}` | `https://${string}`, string>>;
    registration_endpoint: z.ZodOptional<z.ZodEffects<z.ZodString, `http://[::1]${string}` | "http://localhost" | `http://localhost#${string}` | `http://localhost?${string}` | `http://localhost/${string}` | `http://localhost:${string}` | "http://127.0.0.1" | `http://127.0.0.1#${string}` | `http://127.0.0.1?${string}` | `http://127.0.0.1/${string}` | `http://127.0.0.1:${string}` | `https://${string}`, string>>;
    dpop_signing_alg_values_supported: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
    protected_resources: z.ZodOptional<z.ZodArray<z.ZodEffects<z.ZodString, `http://[::1]${string}` | "http://localhost" | `http://localhost#${string}` | `http://localhost?${string}` | `http://localhost/${string}` | `http://localhost:${string}` | "http://127.0.0.1" | `http://127.0.0.1#${string}` | `http://127.0.0.1?${string}` | `http://127.0.0.1/${string}` | `http://127.0.0.1:${string}` | `https://${string}`, string>, "many">>;
    client_id_metadata_document_supported: z.ZodOptional<z.ZodBoolean>;
}, "strip", z.ZodTypeAny, {
    issuer: `http://[::1]${string}` | "http://localhost" | `http://localhost#${string}` | `http://localhost?${string}` | `http://localhost/${string}` | `http://localhost:${string}` | "http://127.0.0.1" | `http://127.0.0.1#${string}` | `http://127.0.0.1?${string}` | `http://127.0.0.1/${string}` | `http://127.0.0.1:${string}` | `https://${string}`;
    authorization_endpoint: `http://[::1]${string}` | "http://localhost" | `http://localhost#${string}` | `http://localhost?${string}` | `http://localhost/${string}` | `http://localhost:${string}` | "http://127.0.0.1" | `http://127.0.0.1#${string}` | `http://127.0.0.1?${string}` | `http://127.0.0.1/${string}` | `http://127.0.0.1:${string}` | `https://${string}`;
    token_endpoint: `http://[::1]${string}` | "http://localhost" | `http://localhost#${string}` | `http://localhost?${string}` | `http://localhost/${string}` | `http://localhost:${string}` | "http://127.0.0.1" | `http://127.0.0.1#${string}` | `http://127.0.0.1?${string}` | `http://127.0.0.1/${string}` | `http://127.0.0.1:${string}` | `https://${string}`;
    jwks_uri?: `http://[::1]${string}` | "http://localhost" | `http://localhost#${string}` | `http://localhost?${string}` | `http://localhost/${string}` | `http://localhost:${string}` | "http://127.0.0.1" | `http://127.0.0.1#${string}` | `http://127.0.0.1?${string}` | `http://127.0.0.1/${string}` | `http://127.0.0.1:${string}` | `https://${string}` | undefined;
    claims_supported?: string[] | undefined;
    claims_locales_supported?: string[] | undefined;
    claims_parameter_supported?: boolean | undefined;
    request_parameter_supported?: boolean | undefined;
    request_uri_parameter_supported?: boolean | undefined;
    require_request_uri_registration?: boolean | undefined;
    scopes_supported?: string[] | undefined;
    subject_types_supported?: string[] | undefined;
    response_types_supported?: string[] | undefined;
    response_modes_supported?: string[] | undefined;
    grant_types_supported?: string[] | undefined;
    code_challenge_methods_supported?: ("S256" | "plain")[] | undefined;
    ui_locales_supported?: string[] | undefined;
    id_token_signing_alg_values_supported?: string[] | undefined;
    display_values_supported?: string[] | undefined;
    request_object_signing_alg_values_supported?: string[] | undefined;
    authorization_response_iss_parameter_supported?: boolean | undefined;
    authorization_details_types_supported?: string[] | undefined;
    request_object_encryption_alg_values_supported?: string[] | undefined;
    request_object_encryption_enc_values_supported?: string[] | undefined;
    token_endpoint_auth_methods_supported?: string[] | undefined;
    token_endpoint_auth_signing_alg_values_supported?: string[] | undefined;
    revocation_endpoint?: `http://[::1]${string}` | "http://localhost" | `http://localhost#${string}` | `http://localhost?${string}` | `http://localhost/${string}` | `http://localhost:${string}` | "http://127.0.0.1" | `http://127.0.0.1#${string}` | `http://127.0.0.1?${string}` | `http://127.0.0.1/${string}` | `http://127.0.0.1:${string}` | `https://${string}` | undefined;
    introspection_endpoint?: `http://[::1]${string}` | "http://localhost" | `http://localhost#${string}` | `http://localhost?${string}` | `http://localhost/${string}` | `http://localhost:${string}` | "http://127.0.0.1" | `http://127.0.0.1#${string}` | `http://127.0.0.1?${string}` | `http://127.0.0.1/${string}` | `http://127.0.0.1:${string}` | `https://${string}` | undefined;
    pushed_authorization_request_endpoint?: `http://[::1]${string}` | "http://localhost" | `http://localhost#${string}` | `http://localhost?${string}` | `http://localhost/${string}` | `http://localhost:${string}` | "http://127.0.0.1" | `http://127.0.0.1#${string}` | `http://127.0.0.1?${string}` | `http://127.0.0.1/${string}` | `http://127.0.0.1:${string}` | `https://${string}` | undefined;
    require_pushed_authorization_requests?: boolean | undefined;
    userinfo_endpoint?: `http://[::1]${string}` | "http://localhost" | `http://localhost#${string}` | `http://localhost?${string}` | `http://localhost/${string}` | `http://localhost:${string}` | "http://127.0.0.1" | `http://127.0.0.1#${string}` | `http://127.0.0.1?${string}` | `http://127.0.0.1/${string}` | `http://127.0.0.1:${string}` | `https://${string}` | undefined;
    end_session_endpoint?: `http://[::1]${string}` | "http://localhost" | `http://localhost#${string}` | `http://localhost?${string}` | `http://localhost/${string}` | `http://localhost:${string}` | "http://127.0.0.1" | `http://127.0.0.1#${string}` | `http://127.0.0.1?${string}` | `http://127.0.0.1/${string}` | `http://127.0.0.1:${string}` | `https://${string}` | undefined;
    registration_endpoint?: `http://[::1]${string}` | "http://localhost" | `http://localhost#${string}` | `http://localhost?${string}` | `http://localhost/${string}` | `http://localhost:${string}` | "http://127.0.0.1" | `http://127.0.0.1#${string}` | `http://127.0.0.1?${string}` | `http://127.0.0.1/${string}` | `http://127.0.0.1:${string}` | `https://${string}` | undefined;
    dpop_signing_alg_values_supported?: string[] | undefined;
    protected_resources?: (`http://[::1]${string}` | "http://localhost" | `http://localhost#${string}` | `http://localhost?${string}` | `http://localhost/${string}` | `http://localhost:${string}` | "http://127.0.0.1" | `http://127.0.0.1#${string}` | `http://127.0.0.1?${string}` | `http://127.0.0.1/${string}` | `http://127.0.0.1:${string}` | `https://${string}`)[] | undefined;
    client_id_metadata_document_supported?: boolean | undefined;
}, {
    issuer: string;
    authorization_endpoint: string;
    token_endpoint: string;
    jwks_uri?: string | undefined;
    claims_supported?: string[] | undefined;
    claims_locales_supported?: string[] | undefined;
    claims_parameter_supported?: boolean | undefined;
    request_parameter_supported?: boolean | undefined;
    request_uri_parameter_supported?: boolean | undefined;
    require_request_uri_registration?: boolean | undefined;
    scopes_supported?: string[] | undefined;
    subject_types_supported?: string[] | undefined;
    response_types_supported?: string[] | undefined;
    response_modes_supported?: string[] | undefined;
    grant_types_supported?: string[] | undefined;
    code_challenge_methods_supported?: ("S256" | "plain")[] | undefined;
    ui_locales_supported?: string[] | undefined;
    id_token_signing_alg_values_supported?: string[] | undefined;
    display_values_supported?: string[] | undefined;
    request_object_signing_alg_values_supported?: string[] | undefined;
    authorization_response_iss_parameter_supported?: boolean | undefined;
    authorization_details_types_supported?: string[] | undefined;
    request_object_encryption_alg_values_supported?: string[] | undefined;
    request_object_encryption_enc_values_supported?: string[] | undefined;
    token_endpoint_auth_methods_supported?: string[] | undefined;
    token_endpoint_auth_signing_alg_values_supported?: string[] | undefined;
    revocation_endpoint?: string | undefined;
    introspection_endpoint?: string | undefined;
    pushed_authorization_request_endpoint?: string | undefined;
    require_pushed_authorization_requests?: boolean | undefined;
    userinfo_endpoint?: string | undefined;
    end_session_endpoint?: string | undefined;
    registration_endpoint?: string | undefined;
    dpop_signing_alg_values_supported?: string[] | undefined;
    protected_resources?: string[] | undefined;
    client_id_metadata_document_supported?: boolean | undefined;
}>, {
    issuer: `http://[::1]${string}` | "http://localhost" | `http://localhost#${string}` | `http://localhost?${string}` | `http://localhost/${string}` | `http://localhost:${string}` | "http://127.0.0.1" | `http://127.0.0.1#${string}` | `http://127.0.0.1?${string}` | `http://127.0.0.1/${string}` | `http://127.0.0.1:${string}` | `https://${string}`;
    authorization_endpoint: `http://[::1]${string}` | "http://localhost" | `http://localhost#${string}` | `http://localhost?${string}` | `http://localhost/${string}` | `http://localhost:${string}` | "http://127.0.0.1" | `http://127.0.0.1#${string}` | `http://127.0.0.1?${string}` | `http://127.0.0.1/${string}` | `http://127.0.0.1:${string}` | `https://${string}`;
    token_endpoint: `http://[::1]${string}` | "http://localhost" | `http://localhost#${string}` | `http://localhost?${string}` | `http://localhost/${string}` | `http://localhost:${string}` | "http://127.0.0.1" | `http://127.0.0.1#${string}` | `http://127.0.0.1?${string}` | `http://127.0.0.1/${string}` | `http://127.0.0.1:${string}` | `https://${string}`;
    jwks_uri?: `http://[::1]${string}` | "http://localhost" | `http://localhost#${string}` | `http://localhost?${string}` | `http://localhost/${string}` | `http://localhost:${string}` | "http://127.0.0.1" | `http://127.0.0.1#${string}` | `http://127.0.0.1?${string}` | `http://127.0.0.1/${string}` | `http://127.0.0.1:${string}` | `https://${string}` | undefined;
    claims_supported?: string[] | undefined;
    claims_locales_supported?: string[] | undefined;
    claims_parameter_supported?: boolean | undefined;
    request_parameter_supported?: boolean | undefined;
    request_uri_parameter_supported?: boolean | undefined;
    require_request_uri_registration?: boolean | undefined;
    scopes_supported?: string[] | undefined;
    subject_types_supported?: string[] | undefined;
    response_types_supported?: string[] | undefined;
    response_modes_supported?: string[] | undefined;
    grant_types_supported?: string[] | undefined;
    code_challenge_methods_supported?: ("S256" | "plain")[] | undefined;
    ui_locales_supported?: string[] | undefined;
    id_token_signing_alg_values_supported?: string[] | undefined;
    display_values_supported?: string[] | undefined;
    request_object_signing_alg_values_supported?: string[] | undefined;
    authorization_response_iss_parameter_supported?: boolean | undefined;
    authorization_details_types_supported?: string[] | undefined;
    request_object_encryption_alg_values_supported?: string[] | undefined;
    request_object_encryption_enc_values_supported?: string[] | undefined;
    token_endpoint_auth_methods_supported?: string[] | undefined;
    token_endpoint_auth_signing_alg_values_supported?: string[] | undefined;
    revocation_endpoint?: `http://[::1]${string}` | "http://localhost" | `http://localhost#${string}` | `http://localhost?${string}` | `http://localhost/${string}` | `http://localhost:${string}` | "http://127.0.0.1" | `http://127.0.0.1#${string}` | `http://127.0.0.1?${string}` | `http://127.0.0.1/${string}` | `http://127.0.0.1:${string}` | `https://${string}` | undefined;
    introspection_endpoint?: `http://[::1]${string}` | "http://localhost" | `http://localhost#${string}` | `http://localhost?${string}` | `http://localhost/${string}` | `http://localhost:${string}` | "http://127.0.0.1" | `http://127.0.0.1#${string}` | `http://127.0.0.1?${string}` | `http://127.0.0.1/${string}` | `http://127.0.0.1:${string}` | `https://${string}` | undefined;
    pushed_authorization_request_endpoint?: `http://[::1]${string}` | "http://localhost" | `http://localhost#${string}` | `http://localhost?${string}` | `http://localhost/${string}` | `http://localhost:${string}` | "http://127.0.0.1" | `http://127.0.0.1#${string}` | `http://127.0.0.1?${string}` | `http://127.0.0.1/${string}` | `http://127.0.0.1:${string}` | `https://${string}` | undefined;
    require_pushed_authorization_requests?: boolean | undefined;
    userinfo_endpoint?: `http://[::1]${string}` | "http://localhost" | `http://localhost#${string}` | `http://localhost?${string}` | `http://localhost/${string}` | `http://localhost:${string}` | "http://127.0.0.1" | `http://127.0.0.1#${string}` | `http://127.0.0.1?${string}` | `http://127.0.0.1/${string}` | `http://127.0.0.1:${string}` | `https://${string}` | undefined;
    end_session_endpoint?: `http://[::1]${string}` | "http://localhost" | `http://localhost#${string}` | `http://localhost?${string}` | `http://localhost/${string}` | `http://localhost:${string}` | "http://127.0.0.1" | `http://127.0.0.1#${string}` | `http://127.0.0.1?${string}` | `http://127.0.0.1/${string}` | `http://127.0.0.1:${string}` | `https://${string}` | undefined;
    registration_endpoint?: `http://[::1]${string}` | "http://localhost" | `http://localhost#${string}` | `http://localhost?${string}` | `http://localhost/${string}` | `http://localhost:${string}` | "http://127.0.0.1" | `http://127.0.0.1#${string}` | `http://127.0.0.1?${string}` | `http://127.0.0.1/${string}` | `http://127.0.0.1:${string}` | `https://${string}` | undefined;
    dpop_signing_alg_values_supported?: string[] | undefined;
    protected_resources?: (`http://[::1]${string}` | "http://localhost" | `http://localhost#${string}` | `http://localhost?${string}` | `http://localhost/${string}` | `http://localhost:${string}` | "http://127.0.0.1" | `http://127.0.0.1#${string}` | `http://127.0.0.1?${string}` | `http://127.0.0.1/${string}` | `http://127.0.0.1:${string}` | `https://${string}`)[] | undefined;
    client_id_metadata_document_supported?: boolean | undefined;
}, {
    issuer: string;
    authorization_endpoint: string;
    token_endpoint: string;
    jwks_uri?: string | undefined;
    claims_supported?: string[] | undefined;
    claims_locales_supported?: string[] | undefined;
    claims_parameter_supported?: boolean | undefined;
    request_parameter_supported?: boolean | undefined;
    request_uri_parameter_supported?: boolean | undefined;
    require_request_uri_registration?: boolean | undefined;
    scopes_supported?: string[] | undefined;
    subject_types_supported?: string[] | undefined;
    response_types_supported?: string[] | undefined;
    response_modes_supported?: string[] | undefined;
    grant_types_supported?: string[] | undefined;
    code_challenge_methods_supported?: ("S256" | "plain")[] | undefined;
    ui_locales_supported?: string[] | undefined;
    id_token_signing_alg_values_supported?: string[] | undefined;
    display_values_supported?: string[] | undefined;
    request_object_signing_alg_values_supported?: string[] | undefined;
    authorization_response_iss_parameter_supported?: boolean | undefined;
    authorization_details_types_supported?: string[] | undefined;
    request_object_encryption_alg_values_supported?: string[] | undefined;
    request_object_encryption_enc_values_supported?: string[] | undefined;
    token_endpoint_auth_methods_supported?: string[] | undefined;
    token_endpoint_auth_signing_alg_values_supported?: string[] | undefined;
    revocation_endpoint?: string | undefined;
    introspection_endpoint?: string | undefined;
    pushed_authorization_request_endpoint?: string | undefined;
    require_pushed_authorization_requests?: boolean | undefined;
    userinfo_endpoint?: string | undefined;
    end_session_endpoint?: string | undefined;
    registration_endpoint?: string | undefined;
    dpop_signing_alg_values_supported?: string[] | undefined;
    protected_resources?: string[] | undefined;
    client_id_metadata_document_supported?: boolean | undefined;
}>, {
    issuer: `http://[::1]${string}` | "http://localhost" | `http://localhost#${string}` | `http://localhost?${string}` | `http://localhost/${string}` | `http://localhost:${string}` | "http://127.0.0.1" | `http://127.0.0.1#${string}` | `http://127.0.0.1?${string}` | `http://127.0.0.1/${string}` | `http://127.0.0.1:${string}` | `https://${string}`;
    authorization_endpoint: `http://[::1]${string}` | "http://localhost" | `http://localhost#${string}` | `http://localhost?${string}` | `http://localhost/${string}` | `http://localhost:${string}` | "http://127.0.0.1" | `http://127.0.0.1#${string}` | `http://127.0.0.1?${string}` | `http://127.0.0.1/${string}` | `http://127.0.0.1:${string}` | `https://${string}`;
    token_endpoint: `http://[::1]${string}` | "http://localhost" | `http://localhost#${string}` | `http://localhost?${string}` | `http://localhost/${string}` | `http://localhost:${string}` | "http://127.0.0.1" | `http://127.0.0.1#${string}` | `http://127.0.0.1?${string}` | `http://127.0.0.1/${string}` | `http://127.0.0.1:${string}` | `https://${string}`;
    jwks_uri?: `http://[::1]${string}` | "http://localhost" | `http://localhost#${string}` | `http://localhost?${string}` | `http://localhost/${string}` | `http://localhost:${string}` | "http://127.0.0.1" | `http://127.0.0.1#${string}` | `http://127.0.0.1?${string}` | `http://127.0.0.1/${string}` | `http://127.0.0.1:${string}` | `https://${string}` | undefined;
    claims_supported?: string[] | undefined;
    claims_locales_supported?: string[] | undefined;
    claims_parameter_supported?: boolean | undefined;
    request_parameter_supported?: boolean | undefined;
    request_uri_parameter_supported?: boolean | undefined;
    require_request_uri_registration?: boolean | undefined;
    scopes_supported?: string[] | undefined;
    subject_types_supported?: string[] | undefined;
    response_types_supported?: string[] | undefined;
    response_modes_supported?: string[] | undefined;
    grant_types_supported?: string[] | undefined;
    code_challenge_methods_supported?: ("S256" | "plain")[] | undefined;
    ui_locales_supported?: string[] | undefined;
    id_token_signing_alg_values_supported?: string[] | undefined;
    display_values_supported?: string[] | undefined;
    request_object_signing_alg_values_supported?: string[] | undefined;
    authorization_response_iss_parameter_supported?: boolean | undefined;
    authorization_details_types_supported?: string[] | undefined;
    request_object_encryption_alg_values_supported?: string[] | undefined;
    request_object_encryption_enc_values_supported?: string[] | undefined;
    token_endpoint_auth_methods_supported?: string[] | undefined;
    token_endpoint_auth_signing_alg_values_supported?: string[] | undefined;
    revocation_endpoint?: `http://[::1]${string}` | "http://localhost" | `http://localhost#${string}` | `http://localhost?${string}` | `http://localhost/${string}` | `http://localhost:${string}` | "http://127.0.0.1" | `http://127.0.0.1#${string}` | `http://127.0.0.1?${string}` | `http://127.0.0.1/${string}` | `http://127.0.0.1:${string}` | `https://${string}` | undefined;
    introspection_endpoint?: `http://[::1]${string}` | "http://localhost" | `http://localhost#${string}` | `http://localhost?${string}` | `http://localhost/${string}` | `http://localhost:${string}` | "http://127.0.0.1" | `http://127.0.0.1#${string}` | `http://127.0.0.1?${string}` | `http://127.0.0.1/${string}` | `http://127.0.0.1:${string}` | `https://${string}` | undefined;
    pushed_authorization_request_endpoint?: `http://[::1]${string}` | "http://localhost" | `http://localhost#${string}` | `http://localhost?${string}` | `http://localhost/${string}` | `http://localhost:${string}` | "http://127.0.0.1" | `http://127.0.0.1#${string}` | `http://127.0.0.1?${string}` | `http://127.0.0.1/${string}` | `http://127.0.0.1:${string}` | `https://${string}` | undefined;
    require_pushed_authorization_requests?: boolean | undefined;
    userinfo_endpoint?: `http://[::1]${string}` | "http://localhost" | `http://localhost#${string}` | `http://localhost?${string}` | `http://localhost/${string}` | `http://localhost:${string}` | "http://127.0.0.1" | `http://127.0.0.1#${string}` | `http://127.0.0.1?${string}` | `http://127.0.0.1/${string}` | `http://127.0.0.1:${string}` | `https://${string}` | undefined;
    end_session_endpoint?: `http://[::1]${string}` | "http://localhost" | `http://localhost#${string}` | `http://localhost?${string}` | `http://localhost/${string}` | `http://localhost:${string}` | "http://127.0.0.1" | `http://127.0.0.1#${string}` | `http://127.0.0.1?${string}` | `http://127.0.0.1/${string}` | `http://127.0.0.1:${string}` | `https://${string}` | undefined;
    registration_endpoint?: `http://[::1]${string}` | "http://localhost" | `http://localhost#${string}` | `http://localhost?${string}` | `http://localhost/${string}` | `http://localhost:${string}` | "http://127.0.0.1" | `http://127.0.0.1#${string}` | `http://127.0.0.1?${string}` | `http://127.0.0.1/${string}` | `http://127.0.0.1:${string}` | `https://${string}` | undefined;
    dpop_signing_alg_values_supported?: string[] | undefined;
    protected_resources?: (`http://[::1]${string}` | "http://localhost" | `http://localhost#${string}` | `http://localhost?${string}` | `http://localhost/${string}` | `http://localhost:${string}` | "http://127.0.0.1" | `http://127.0.0.1#${string}` | `http://127.0.0.1?${string}` | `http://127.0.0.1/${string}` | `http://127.0.0.1:${string}` | `https://${string}`)[] | undefined;
    client_id_metadata_document_supported?: boolean | undefined;
}, {
    issuer: string;
    authorization_endpoint: string;
    token_endpoint: string;
    jwks_uri?: string | undefined;
    claims_supported?: string[] | undefined;
    claims_locales_supported?: string[] | undefined;
    claims_parameter_supported?: boolean | undefined;
    request_parameter_supported?: boolean | undefined;
    request_uri_parameter_supported?: boolean | undefined;
    require_request_uri_registration?: boolean | undefined;
    scopes_supported?: string[] | undefined;
    subject_types_supported?: string[] | undefined;
    response_types_supported?: string[] | undefined;
    response_modes_supported?: string[] | undefined;
    grant_types_supported?: string[] | undefined;
    code_challenge_methods_supported?: ("S256" | "plain")[] | undefined;
    ui_locales_supported?: string[] | undefined;
    id_token_signing_alg_values_supported?: string[] | undefined;
    display_values_supported?: string[] | undefined;
    request_object_signing_alg_values_supported?: string[] | undefined;
    authorization_response_iss_parameter_supported?: boolean | undefined;
    authorization_details_types_supported?: string[] | undefined;
    request_object_encryption_alg_values_supported?: string[] | undefined;
    request_object_encryption_enc_values_supported?: string[] | undefined;
    token_endpoint_auth_methods_supported?: string[] | undefined;
    token_endpoint_auth_signing_alg_values_supported?: string[] | undefined;
    revocation_endpoint?: string | undefined;
    introspection_endpoint?: string | undefined;
    pushed_authorization_request_endpoint?: string | undefined;
    require_pushed_authorization_requests?: boolean | undefined;
    userinfo_endpoint?: string | undefined;
    end_session_endpoint?: string | undefined;
    registration_endpoint?: string | undefined;
    dpop_signing_alg_values_supported?: string[] | undefined;
    protected_resources?: string[] | undefined;
    client_id_metadata_document_supported?: boolean | undefined;
}>;
//# sourceMappingURL=oauth-authorization-server-metadata.d.ts.map